@@ -1,27 +1,16 @@
 /*
-    Copyright (c) 2007 David Faure <faure@kde.org>
+    SPDX-FileCopyrightText: 2007 David Faure <faure@kde.org>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
+
 #include "parttest.h"
 #include <qtest_widgets.h>
 
-#include <ksharedconfig.h>
+#include <KSharedConfig>
 #include <kparts/readonlypart.h>
 #include <kparts/openurlarguments.h>
+#include <QSignalSpy>
 #include <QTest>
 #include <QWidget>
 
@@ -42,7 +31,7 @@ public:
         return m_openFileCalled;
     }
 protected:
-    bool openFile() Q_DECL_OVERRIDE
+    bool openFile() override
     {
         m_openFileCalled = true;
         return true;
@@ -53,37 +42,37 @@ private:
 
 void PartTest::testAutoDeletePart()
 {
-    KParts::Part *part = new TestPart(0, 0);
+    KParts::Part *part = new TestPart(nullptr, nullptr);
     QPointer<KParts::Part> partPointer(part);
     delete part->widget();
-    QCoreApplication::sendPostedEvents(0, QEvent::DeferredDelete);
+    QCoreApplication::sendPostedEvents(nullptr, QEvent::DeferredDelete);
     QVERIFY(partPointer.isNull());
 }
 
 void PartTest::testAutoDeleteWidget()
 {
-    KParts::Part *part = new TestPart(0, 0);
+    KParts::Part *part = new TestPart(nullptr, nullptr);
     QPointer<KParts::Part> partPointer(part);
     QPointer<QWidget> widgetPointer(part->widget());
     delete part;
-    QCoreApplication::sendPostedEvents(0, QEvent::DeferredDelete);
+    QCoreApplication::sendPostedEvents(nullptr, QEvent::DeferredDelete);
     QVERIFY(widgetPointer.isNull());
 }
 
 void PartTest::testNoAutoDeletePart()
 {
-    KParts::Part *part = new TestPart(0, 0);
+    KParts::Part *part = new TestPart(nullptr, nullptr);
     part->setAutoDeletePart(false);
     QPointer<KParts::Part> partPointer(part);
     delete part->widget();
-    QVERIFY(part->widget() == 0);
+    QVERIFY(part->widget() == nullptr);
     QCOMPARE(static_cast<KParts::Part *>(partPointer), part);
     delete part;
 }
 
 void PartTest::testNoAutoDeleteWidget()
 {
-    KParts::Part *part = new TestPart(0, 0);
+    KParts::Part *part = new TestPart(nullptr, nullptr);
     part->setAutoDeleteWidget(false);
     QWidget *widget = part->widget();
     QVERIFY(widget);
@@ -105,7 +94,7 @@ static bool compareArgs(const KParts::OpenUrlArguments &arg1,
 
 void PartTest::testOpenUrlArguments()
 {
-    TestPart *part = new TestPart(0, 0);
+    TestPart *part = new TestPart(nullptr, nullptr);
     QVERIFY(part->closeUrl()); // nothing to do, no error
     QVERIFY(part->arguments().mimeType().isEmpty());
     KParts::OpenUrlArguments args;
@@ -133,7 +122,7 @@ void PartTest::testOpenUrlArguments()
 
 void PartTest::testAutomaticMimeType()
 {
-    TestPart *part = new TestPart(0, 0);
+    TestPart *part = new TestPart(nullptr, nullptr);
     QVERIFY(part->closeUrl()); // nothing to do, no error
     QVERIFY(part->arguments().mimeType().isEmpty());
     // open a file, and test the detected mimetype
@@ -170,10 +159,27 @@ void PartTest::testAutomaticMimeType()
     delete part;
 }
 
+void PartTest::testEmptyUrlAfterCloseUrl()
+{
+    TestPart *part = new TestPart(nullptr, nullptr);
+
+    QVERIFY(part->openUrl(QUrl::fromLocalFile(QFINDTESTDATA("notepad.desktop"))));
+    QSignalSpy spy(part, &KParts::ReadOnlyPart::urlChanged);
+    QVERIFY(part->openUrl(QUrl::fromLocalFile(QFINDTESTDATA("parttest.cpp"))));
+    QVERIFY(!part->url().isEmpty());
+    QCOMPARE(spy.count(), 1);
+    spy.clear();
+    QVERIFY(part->closeUrl());
+    QVERIFY(part->url().isEmpty());
+    QCOMPARE(spy.count(), 1);
+
+    delete part;
+}
+
 #include <kparts/mainwindow.h>
-#include <ktoolbar.h>
-#include <kconfiggroup.h>
-#include <ktoggletoolbaraction.h>
+#include <KToolBar>
+#include <KConfigGroup>
+#include <KToggleToolBarAction>
 class MyMainWindow : public KParts::MainWindow
 {
 public:
@@ -188,7 +194,7 @@ public:
     {
         QVERIFY(tb->isVisible());
 
-        TestPart *part = new TestPart(0, 0);
+        TestPart *part = new TestPart(nullptr, nullptr);
         // TODO define xml with a toolbar for the part
         // and put some saved settings into qttestrc in order to test
         // r347935+r348051, i.e. the fact that KParts::MainWindow::createGUI
@@ -200,14 +206,14 @@ public:
         this->saveAutoSaveSettings();
 
         // Hide the toolbar using the action (so that setSettingsDirty is called, too)
-        KToggleToolBarAction action(tb, QString(), 0);
+        KToggleToolBarAction action(tb, QString(), nullptr);
         action.trigger();
         QVERIFY(!tb->isVisible());
 
         // Switch the active part, and check that
         // the toolbar doesn't magically reappear,
         // as it did when createGUI was calling applyMainWindowSettings
-        this->createGUI(0);
+        this->createGUI(nullptr);
         QVERIFY(!tb->isVisible());
         this->createGUI(part);
         QVERIFY(!tb->isVisible());
