@@ -1,21 +1,7 @@
 /*
-    Copyright (c) 2009, 2010 David Faure <faure@kde.org>
+    SPDX-FileCopyrightText: 2009, 2010 David Faure <faure@kde.org>
 
-    This library is free software; you can redistribute it and/or modify
-    it under the terms of the GNU Lesser General Public License as published by
-    the Free Software Foundation; either version 2 of the License or ( at
-    your option ) version 3 or, at the discretion of KDE e.V. ( which shall
-    act as a proxy as in section 14 of the GPLv3 ), any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Lesser General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 */
 
 #include "browseropenorsavequestion.h"
@@ -25,7 +11,6 @@
 #include <KLocalizedString>
 #include <KFileItemActions>
 #include <KSqueezedTextLabel>
-#include <KMimeTypeTrader>
 #include <KStandardGuiItem>
 #include <KGuiItem>
 #include <KMessageBox>
