@@ -1,44 +1,37 @@
-/* This file is part of the KDE project
- *
- * Copyright (C) 2002 David Faure <faure@kde.org>
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License version 2, as published by the Free Software Foundation.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public License
- * along with this library; see the file COPYING.LIB.  If not, write to
- * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
- */
+/*
+    This file is part of the KDE project
+
+    SPDX-FileCopyrightText: 2002 David Faure <faure@kde.org>
+    SPDX-License-Identifier: LGPL-2.0-only
+*/
 
 #include "browserrun.h"
 
 #include "browseropenorsavequestion.h"
 
-#include <kconfiggroup.h>
-#include <ksharedconfig.h>
-#include <kmessagebox.h>
+#include "kparts_logging.h"
+
+#include <KConfigGroup>
+#include <KSharedConfig>
+#include <KMessageBox>
+#include <KIO/CommandLauncherJob>
+#include <KIO/OpenUrlJob>
 #include <kio/job.h>
 #include <kio/jobuidelegate.h>
 #include <kio/scheduler.h>
 #include <kio/copyjob.h>
-#include <kjobwidgets.h>
-#include <klocalizedstring.h>
-#include <kshell.h>
-#include <kmimetypetrader.h>
-#include <kprotocolmanager.h>
+#include <KJobWidgets>
+#include <KLocalizedString>
+#include <KShell>
+#include <KProtocolManager>
 
 #include <QTemporaryFile>
 #include <QMimeDatabase>
-#include <QDebug>
 #include <QStandardPaths>
 #include <QFileDialog>
 
+#if KIOWIDGETS_ENABLE_DEPRECATED_SINCE(5, 71)
+
 using namespace KParts;
 
 class Q_DECL_HIDDEN BrowserRun::BrowserRunPrivate
@@ -173,7 +166,7 @@ void BrowserRun::scanFile()
     KJobWidgets::setWindow(job, d->m_window);
     connect(job, &KIO::TransferJob::result,
             this, &BrowserRun::slotBrowserScanFinished);
-    connect(job, static_cast<void (KIO::TransferJob::*)(KIO::Job*,const QString &)>(&KIO::TransferJob::mimetype),
+    connect(job, &KIO::TransferJob::mimeTypeFound,
             this, &BrowserRun::slotBrowserMimetype);
     setJob(job);
 }
@@ -397,31 +390,31 @@ void KParts::BrowserRun::saveUrl(const QUrl &url, const QString &suggestedFileNa
     // only use the downloadmanager for non-local urls
     if (!url.isLocalFile()) {
         KConfigGroup cfg = KSharedConfig::openConfig(QStringLiteral("konquerorrc"), KConfig::NoGlobals)->group("HTML Settings");
-        QString downloadManger = cfg.readPathEntry("DownloadManager", QString());
-        if (!downloadManger.isEmpty()) {
+        QString downloadManager = cfg.readPathEntry("DownloadManager", QString());
+        if (!downloadManager.isEmpty()) {
             // then find the download manager location
-            // qDebug() << "Using: "<<downloadManger <<" as Download Manager";
-            QString cmd = QStandardPaths::findExecutable(downloadManger);
-            if (cmd.isEmpty()) {
-                QString errMsg = i18n("The Download Manager (%1) could not be found in your $PATH ", downloadManger);
+            // qDebug() << "Using: "<<downloadManager <<" as Download Manager";
+            if (QStandardPaths::findExecutable(downloadManager).isEmpty()) {
+                QString errMsg = i18n("The Download Manager (%1) could not be found in your $PATH ", downloadManager);
                 QString errMsgEx = i18n("Try to reinstall it  \n\nThe integration with Konqueror will be disabled.");
                 KMessageBox::detailedSorry(nullptr, errMsg, errMsgEx);
                 cfg.writePathEntry("DownloadManager", QString());
                 cfg.sync();
             } else {
-                // ### suggestedFileName not taken into account. Fix this (and
-                // the duplicated code) with shiny new KDownload class for 3.2 (pfeiffer)
-                // Until the shiny new class comes about, send the suggestedFileName
-                // along with the actual URL to download. (DA)
-                cmd += QLatin1Char(' ') + KShell::quoteArg(url.toString());
+                QStringList args;
+                args << url.toString();
                 if (!suggestedFileName.isEmpty()) {
-                    cmd += QLatin1Char(' ') + KShell::quoteArg(suggestedFileName);
+                    args << suggestedFileName;
                 }
 
-                // qDebug() << "Calling command" << cmd;
+                // qDebug() << "Calling command" << downloadManager << args;
                 // slave is already on hold (slotBrowserMimetype())
                 KIO::Scheduler::publishSlaveOnHold();
-                KRun::runCommand(cmd, window);
+
+                auto *job = new KIO::CommandLauncherJob(downloadManager, args);
+                job->setExecutable(downloadManager);
+                job->setUiDelegate(new KDialogJobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, window));
+                job->start();
                 return;
             }
         }
@@ -432,6 +425,7 @@ void KParts::BrowserRun::saveUrl(const QUrl &url, const QString &suggestedFileNa
     dlg->setAcceptMode(QFileDialog::AcceptSave);
     dlg->setWindowTitle(i18n("Save As"));
     dlg->setOption(QFileDialog::DontConfirmOverwrite, false);
+    dlg->setAttribute(Qt::WA_DeleteOnClose);
 
     QString name;
     if (!suggestedFileName.isEmpty()) {
@@ -441,13 +435,14 @@ void KParts::BrowserRun::saveUrl(const QUrl &url, const QString &suggestedFileNa
     }
 
     dlg->selectFile(name);
-    if (dlg->exec()) {
-        QUrl destURL(dlg->selectedUrls().at(0));
+    connect(dlg, &QDialog::accepted, dlg, [dlg, url, window, args]() {
+        const QUrl destURL = dlg->selectedUrls().value(0);
         if (destURL.isValid()) {
             saveUrlUsingKIO(url, destURL, window, args.metaData());
         }
-    }
-    delete dlg;
+    });
+
+    dlg->show();
 }
 
 void BrowserRun::saveUrlUsingKIO(const QUrl &srcUrl, const QUrl &destUrl,
@@ -469,7 +464,7 @@ void BrowserRun::saveUrlUsingKIO(const QUrl &srcUrl, const QUrl &destUrl,
 void BrowserRun::handleError(KJob *job)
 {
     if (!job) {   // Shouldn't happen
-        qWarning() << "handleError called with job=0! hideErrorDialog=" << d->m_bHideErrorDialog;
+        qCWarning(KPARTSLOG) << "handleError called with job=0! hideErrorDialog=" << d->m_bHideErrorDialog;
         return;
     }
 
@@ -536,7 +531,11 @@ void BrowserRun::slotCopyToTempFileResult(KJob *job)
         job->uiDelegate()->showErrorMessage();
     } else {
         // Same as KRun::foundMimeType but with a different URL
-        (void)(KRun::runUrl(static_cast<KIO::FileCopyJob *>(job)->destUrl(), d->m_mimeType, d->m_window, KRun::RunFlags(KRun::RunExecutables)));
+        const QUrl destUrl = static_cast<KIO::FileCopyJob *>(job)->destUrl();
+        KIO::OpenUrlJob *job = new KIO::OpenUrlJob(destUrl, d->m_mimeType);
+        job->setUiDelegate(new KIO::JobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, d->m_window));
+        job->setRunExecutables(true);
+        job->start();
     }
     setError(true);   // see above
     setFinished(true);
@@ -576,3 +575,5 @@ KParts::BrowserArguments &KParts::BrowserRun::browserArguments()
 }
 
 #include "moc_browserrun.cpp"
+
+#endif
