@@ -1,34 +1,26 @@
-/* This file is part of the KDE project
- *
- * Copyright (C) 2002 David Faure <faure@kde.org>
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License version 2, as published by the Free Software Foundation.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public License
- * along with this library; see the file COPYING.LIB.  If not, write to
- * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
- */
+/*
+    This file is part of the KDE project
+
+    SPDX-FileCopyrightText: 2002 David Faure <faure@kde.org>
+    SPDX-License-Identifier: LGPL-2.0-only
+*/
 
 #ifndef kparts_browserrun_h
 #define kparts_browserrun_h
 
 #include <kparts/browserextension.h>
 
-#include <krun.h>
-#include <kservice.h>
+#include <KRun>
+#include <KService>
 
+#if KIOWIDGETS_ENABLE_DEPRECATED_SINCE(5, 71)
 namespace KParts
 {
 
 /**
- * This class extends KRun to provide additional functionality for browsers:
+ * @class BrowserRun browserrun.h <KParts/BrowserRun>
+ *
+ * @short This class extends KRun to provide additional functionality for browsers:
  * - "save or open" dialog boxes
  * - "save" functionality
  * - support for HTTP POST (including saving the result to a temp file if
@@ -46,7 +38,7 @@ public:
      * @param url the URL we're probing
      * @param args URL args - includes reload, metaData, etc.
      * @param browserArgs browser-related args - includes data for a HTTP POST, etc.
-     * @param part the part going to open this URL - can be 0 if not created yet
+     * @param part the part going to open this URL - can be @c nullptr if not created yet
      * @param window the mainwindow - passed to KIO::Job::setWindow()
      * @param removeReferrer if true, the "referrer" metadata from @p args isn't passed on
      * @param trustedSource if false, a warning will be shown before launching an executable.
@@ -79,6 +71,7 @@ public:
      */
     bool serverSuggestsSave() const;
 
+#if KPARTS_ENABLE_DEPRECATED_SINCE(5, 0)
     enum AskSaveResult { Save, Open, Cancel };
     /**
      * Ask the user whether to save or open a url in another application.
@@ -87,17 +80,22 @@ public:
      * @param mimeType the mimetype of the URL
      * @param suggestedFileName optional file name suggested by the server
      * @return Save, Open or Cancel.
-     * @deprecated use BrowserOpenOrSaveQuestion
+     * @deprecated Since 5.0, use BrowserOpenOrSaveQuestion
      * @code
      *  BrowserOpenOrSaveQuestion dlg(parent, url, mimeType, suggestedFileName);
      *  const BrowserOpenOrSaveQuestion::Result res = dlg.askOpenOrSave();
      * @endcode
      */
-#ifndef KPARTS_NO_DEPRECATED
-    static KPARTS_DEPRECATED AskSaveResult askSave(const QUrl &url, KService::Ptr offer, const QString &mimeType, const QString &suggestedFileName = QString());
+    KPARTS_DEPRECATED_VERSION(5, 0, "Use KParts::BrowserOpenOrSaveQuestion")
+    static AskSaveResult askSave(const QUrl &url, KService::Ptr offer, const QString &mimeType, const QString &suggestedFileName = QString());
 #endif
 
+#if KPARTS_ENABLE_DEPRECATED_SINCE(5, 65)
+    /** @deprecated Since 5.65, use BrowserOpenOrSaveQuestion::AskEmbedOrSaveFlags */
     enum AskEmbedOrSaveFlags { InlineDisposition = 0, AttachmentDisposition = 1 };
+#endif
+
+#if KPARTS_ENABLE_DEPRECATED_SINCE(5, 0)
     /**
      * Similar to askSave but for the case where the current application is
      * able to embed the url itself (instead of passing it to another app).
@@ -106,23 +104,30 @@ public:
      * @param suggestedFileName optional filename suggested by the server
      * @param flags set to AttachmentDisposition if suggested by the server
      * @return Save, Open or Cancel.
-     * @deprecated use BrowserOpenOrSaveQuestion
+     * @deprecated Since 5.0, use BrowserOpenOrSaveQuestion
      * @code
      *  BrowserOpenOrSaveQuestion dlg(parent, url, mimeType, suggestedFileName);
      *  const BrowserOpenOrSaveQuestion::Result res = dlg.askEmbedOrSave(flags);
      *  // Important: returns Embed now, not Open!
      * @endcode
      */
-#ifndef KPARTS_NO_DEPRECATED
-    static KPARTS_DEPRECATED AskSaveResult askEmbedOrSave(const QUrl &url, const QString &mimeType, const QString &suggestedFileName = QString(), int flags = 0);
+    KPARTS_DEPRECATED_VERSION(5, 0, "Use KParts::BrowserOpenOrSaveQuestion")
+    static AskSaveResult askEmbedOrSave(const QUrl &url, const QString &mimeType, const QString &suggestedFileName = QString(), int flags = 0);
 #endif
 
     // virtual so that KHTML can implement differently (HTML cache)
     virtual void save(const QUrl &url, const QString &suggestedFileName);
 
-    // static so that it can be called from other classes
+#if KPARTS_ENABLE_DEPRECATED_SINCE(4, 4)
+    /**
+     * static so that it can be called from other classes
+     * @deprecated Since 4.4, use saveUrl(const QUrl &, const QString &, QWidget *, const KParts::OpenUrlArguments &)
+     */
+    KPARTS_DEPRECATED_VERSION(4, 4, "Use BrowserRun::saveUrl(const QUrl &, const QString &, QWidget *, const KParts::OpenUrlArguments &)")
     static void simpleSave(const QUrl &url, const QString &suggestedFileName,
-                           QWidget *window = 0); // KDE5: remove
+                           QWidget *window = nullptr);
+#endif
+
     /**
      * If kget integration is enabled, passes the url to kget.
      * Otherwise, asks the user for a destination url, and calls saveUrlUsingKIO.
@@ -157,15 +162,15 @@ protected:
     /**
      * Reimplemented from KRun
      */
-    void scanFile() Q_DECL_OVERRIDE;
+    void scanFile() override;
     /**
      * Reimplemented from KRun
      */
-    void init() Q_DECL_OVERRIDE;
+    void init() override;
     /**
      * Reimplemented from KRun
      */
-    void handleError(KJob *job) Q_DECL_OVERRIDE;
+    void handleError(KJob *job) override;
 
     /**
      * NotHandled means that foundMimeType should call KRun::foundMimeType,
@@ -212,4 +217,7 @@ private:
 
 };
 }
+
+#endif
+
 #endif
