@@ -1,30 +1,17 @@
 /*
-    Copyright (c) 1999, 2000 David Faure <faure@kde.org>
-    Copyright (c) 1999, 2000 Simon Hausmann <hausmann@kde.org>
+    SPDX-FileCopyrightText: 1999, 2000 David Faure <faure@kde.org>
+    SPDX-FileCopyrightText: 1999, 2000 Simon Hausmann <hausmann@kde.org>
 
-    This library is free software; you can redistribute it and/or modify
-    it under the terms of the GNU Lesser General Public License as published by
-    the Free Software Foundation; either version 2 of the License or ( at
-    your option ) version 3 or, at the discretion of KDE e.V. ( which shall
-    act as a proxy as in section 14 of the GPLv3 ), any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Lesser General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 */
 
 #include "parts.h"
 
 #include "guiactivateevent.h"
 
-#include <kactionmenu.h>
-#include <kactioncollection.h>
+#include <KActionMenu>
+#include <KActionCollection>
+#include <KPluginMetaData>
 
 #include <QAction>
 #include <QCheckBox>
@@ -32,16 +19,23 @@
 #include <QTextStream>
 #include <QTextEdit>
 #include <QLineEdit>
+#include <QJsonDocument>
 #include <QTest>
 
 #include <QDebug>
-#include <klocalizedstring.h>
+#include <KLocalizedString>
+
 
 Part1::Part1(QObject *parent, QWidget *parentWidget)
-    : KParts::ReadOnlyPart(parent),
-      m_componentData(QStringLiteral("kpartstestpart"), i18n("KParts test part"), QStringLiteral("0.1"))
+    : KParts::ReadOnlyPart(parent)
 {
-    setComponentData(m_componentData, false);
+    QJsonObject jo = QJsonDocument::fromJson("{ \"KPlugin\": {\n"
+                                             " \"Id\": \"kpartstestpart\",\n"
+                                             " \"Name\": \"KParts test part\",\n"
+                                             " \"Version\": \"0.1\"\n"
+                                             "}\n}").object();
+    setMetaData(KPluginMetaData(jo, QString()));
+
     m_edit = new QTextEdit(parentWidget);
     setWidget(m_edit);
 
@@ -51,14 +45,14 @@ Part1::Part1(QObject *parent, QWidget *parentWidget)
 
     QAction *testAction = actionCollection()->addAction(QStringLiteral("p1_blah"));
     testAction->setText(QStringLiteral("Part1's action"));
-    actionCollection()->setDefaultShortcut(testAction, Qt::CTRL + Qt::Key_B);
+    actionCollection()->setDefaultShortcut(testAction, Qt::CTRL | Qt::Key_B);
     connect(testAction, SIGNAL(triggered()), this, SLOT(slotBlah()));
 
     KActionMenu *menu = new KActionMenu(QIcon::fromTheme(QStringLiteral("mail_forward")), QStringLiteral("Foo"), this);
     actionCollection()->addAction(QStringLiteral("p1_foo"), menu);
 
     QAction *mailForward = new QAction(QIcon::fromTheme(QStringLiteral("mail_forward")), QStringLiteral("Bar"), this);
-    actionCollection()->setDefaultShortcut(mailForward, Qt::CTRL + Qt::Key_F);
+    actionCollection()->setDefaultShortcut(mailForward, Qt::CTRL | Qt::Key_F);
     connect(mailForward, SIGNAL(triggered()), this, SLOT(slotFooBar()));
     actionCollection()->addAction(QStringLiteral("p1_foo_bar"), mailForward);
     menu->addAction(mailForward);
@@ -103,10 +97,15 @@ bool Part1::openFile()
 }
 
 Part2::Part2(QObject *parent, QWidget *parentWidget)
-    : KParts::Part(parent),
-      m_componentData(QStringLiteral("part2"), QStringLiteral("Part 2"), QStringLiteral("0.2"))
+    : KParts::Part(parent)
 {
-    setComponentData(m_componentData, false);
+    QJsonObject jo = QJsonDocument::fromJson("{ \"KPlugin\": {\n"
+                                             " \"Id\": \"part2\",\n"
+                                             " \"Name\": \"Part 2\",\n"
+                                             " \"Version\": \"0.2\"\n"
+                                             "}\n}").object();
+    setMetaData(KPluginMetaData(jo, QString()));
+
     QWidget *w = new QWidget(parentWidget);
     w->setObjectName(QStringLiteral("Part2Widget"));
     setWidget(w);
